@@ -1,25 +1,20 @@
 #!/usr/bin/env python3
+"""
+This service waits for the guest agent lifecycle event and reissues
+guest agent calls to modify the cpu count according to the metadata
+set by guest-vcpu.py example
+"""
 
 import libvirt
 import threading
 from xml.dom import minidom
 import time
-import sys
-import getopt
-import os
+from argparse import ArgumentParser
 
 uri = "qemu:///system"
 customXMLuri = "guest-cpu.python.libvirt.org"
 connectRetryTimeout = 5
 
-def usage():
-    print("usage: "+os.path.basename(sys.argv[0])+" [-h] [uri]")
-    print("   uri will default to qemu:///system")
-    print("   --help, -h   Print(this help message")
-    print("")
-    print("This service waits for the guest agent lifecycle event and reissues " +
-           "guest agent calls to modify the cpu count according to the metadata " +
-           "set by guest-vcpu.py example")
 
 class workerData:
     def __init__(self):
@@ -67,32 +62,36 @@ def virEventLoopNativeRun():
     while True:
         libvirt.virEventRunDefaultImpl()
 
+
 def handleAgentLifecycleEvent(conn, dom, state, reason, opaque):
     if state == libvirt.VIR_CONNECT_DOMAIN_EVENT_AGENT_LIFECYCLE_STATE_CONNECTED:
         opaque.addDomainNotify(dom)
 
+
 def handleConnectClose(conn, reason, opaque):
     print('Disconnected from ' + uri)
     opaque.closeConnectNotify()
 
+
 def handleLibvirtLibraryError(opaque, error):
     pass
 
+
 def processAgentConnect(dom):
     try:
-        cpus = dom.metadata(libvirt.VIR_DOMAIN_METADATA_ELEMENT, customXMLuri,
-                libvirt.VIR_DOMAIN_AFFECT_LIVE)
+        cpus = dom.metadata(libvirt.VIR_DOMAIN_METADATA_ELEMENT, customXMLuri, libvirt.VIR_DOMAIN_AFFECT_LIVE)
         doc = minidom.parseString(cpus)
         ncpus = int(doc.getElementsByTagName('ncpus')[0].getAttribute('count'))
-    except:
+    except Exception:
         return
 
     try:
         dom.setVcpusFlags(ncpus, libvirt.VIR_DOMAIN_AFFECT_LIVE | libvirt.VIR_DOMAIN_VCPU_GUEST)
         print("set vcpu count for domain " + dom.name() + " to " + str(ncpus))
-    except:
+    except Exception:
         print("failed to set vcpu count for domain " + dom.name())
 
+
 def work():
     data = workerData()
 
@@ -102,7 +101,7 @@ def work():
         if not data.hasConn():
             try:
                 conn = libvirt.open(uri)
-            except:
+            except libvirt.libvirtError:
                 print('Failed to connect to ' + uri + ', retry in ' + str(connectRetryTimeout)) + ' seconds'
                 time.sleep(connectRetryTimeout)
                 continue
@@ -124,6 +123,7 @@ def work():
 
         data.waitNotify()
 
+
 def main():
     libvirt.virEventRegisterDefaultImpl()
     libvirt.registerErrorHandler(handleLibvirtLibraryError, None)
@@ -137,24 +137,14 @@ def main():
     eventLoop.start()
 
     while True:
-       time.sleep(1)
+        time.sleep(1)
+
 
 if __name__ == "__main__":
-    try:
-        opts, args = getopt.getopt(sys.argv[1:], "h", ["help"])
-    except getopt.GetoptError as err:
-        print(str(err))
-        usage()
-        sys.exit(2)
-    for o, a in opts:
-        if o in ("-h", "--help"):
-            usage()
-            sys.exit()
+    parser = ArgumentParser(description=__doc__)
+    parser.add_argument("uri", nargs="?", default=uri)
+    args = parser.parse_args()
 
-    if len(args) > 1:
-        usage()
-        sys.exit(1)
-    elif len(args) == 1:
-        uri = args[0]
+    uri = args.uri
 
     main()
